@@ -215,6 +215,7 @@ enum {
 	FUNCTION_ID_REM = 1734,
 	FUNCTION_ID_MOD = 1735,
 	FUNCTION_ID_BERNOULLI = 1740,
+	FUNCTION_ID_TOTIENT = 1745,
 	FUNCTION_ID_RE = 1750,
 	FUNCTION_ID_IM = 1751,
 	FUNCTION_ID_ARG = 1752,
@@ -235,6 +236,11 @@ enum {
 	FUNCTION_ID_BASE = 1904,
 	FUNCTION_ID_ROMAN = 1905,
 	FUNCTION_ID_BIJECTIVE = 1906,
+	FUNCTION_ID_IEEE754_FLOAT = 1910,
+	FUNCTION_ID_IEEE754_FLOAT_BITS = 1911,
+	FUNCTION_ID_IEEE754_FLOAT_COMPONENTS = 1912,
+	FUNCTION_ID_IEEE754_FLOAT_VALUE = 1913,
+	FUNCTION_ID_IEEE754_FLOAT_ERROR = 1914,
 	FUNCTION_ID_IS_NUMBER = 1920,
 	FUNCTION_ID_IS_REAL = 1921,
 	FUNCTION_ID_IS_RATIONAL = 1922,
@@ -427,6 +433,7 @@ DECLARE_BUILTIN_FUNCTION(FracFunction, FUNCTION_ID_FRAC)
 DECLARE_BUILTIN_FUNCTION(RemFunction, FUNCTION_ID_REM)
 DECLARE_BUILTIN_FUNCTION(ModFunction, FUNCTION_ID_MOD)
 DECLARE_BUILTIN_FUNCTION(BernoulliFunction, FUNCTION_ID_BERNOULLI)
+DECLARE_BUILTIN_FUNCTION(TotientFunction, FUNCTION_ID_TOTIENT)
 
 DECLARE_BUILTIN_FUNCTION(BinFunction, FUNCTION_ID_BIN)
 DECLARE_BUILTIN_FUNCTION(OctFunction, FUNCTION_ID_OCT)
@@ -436,6 +443,12 @@ DECLARE_BUILTIN_FUNCTION(BaseFunction, FUNCTION_ID_BASE)
 DECLARE_BUILTIN_FUNCTION(RomanFunction, FUNCTION_ID_ROMAN)
 DECLARE_BUILTIN_FUNCTION(BijectiveFunction, FUNCTION_ID_BIJECTIVE)
 
+DECLARE_BUILTIN_FUNCTION(IEEE754FloatFunction, FUNCTION_ID_IEEE754_FLOAT)
+DECLARE_BUILTIN_FUNCTION(IEEE754FloatBitsFunction, FUNCTION_ID_IEEE754_FLOAT_BITS)
+DECLARE_BUILTIN_FUNCTION(IEEE754FloatComponentsFunction, FUNCTION_ID_IEEE754_FLOAT_COMPONENTS)
+DECLARE_BUILTIN_FUNCTION(IEEE754FloatValueFunction, FUNCTION_ID_IEEE754_FLOAT_VALUE)
+DECLARE_BUILTIN_FUNCTION(IEEE754FloatErrorFunction, FUNCTION_ID_IEEE754_FLOAT_ERROR)
+
 DECLARE_BUILTIN_FUNCTION(IsNumberFunction, FUNCTION_ID_IS_NUMBER)
 DECLARE_BUILTIN_FUNCTION(IsRealFunction, FUNCTION_ID_IS_REAL)
 DECLARE_BUILTIN_FUNCTION(IsRationalFunction, FUNCTION_ID_IS_RATIONAL)
